import pytest
import syaz0
import wszst_yaz0
from files import TEST_FILES, TEST_FILE_DATA, TEST_FILE_DATA_UNCOMP


@pytest.mark.parametrize("file", TEST_FILES)
def test_decompression(file):
    assert TEST_FILE_DATA_UNCOMP[file] == syaz0.decompress(TEST_FILE_DATA[file])


@pytest.mark.parametrize("file", TEST_FILES)
def test_roundtrip(file):
    assert TEST_FILE_DATA_UNCOMP[file] == syaz0.decompress(syaz0.compress(TEST_FILE_DATA_UNCOMP[file]))




import pytest
import libyaz0
import syaz0
import wszst_yaz0
from files import TEST_FILES, TEST_FILE_DATA


@pytest.mark.parametrize("file", TEST_FILES)
def test_wszst_yaz0(benchmark, file):
    benchmark.group = "decomp: " + file
    wszst_yaz0._use_c_module = False
    benchmark(wszst_yaz0.decompress, TEST_FILE_DATA[file])


@pytest.mark.parametrize("file", TEST_FILES)
def test_wszst_yaz0_c(benchmark, file):
    benchmark.group = "decomp: " + file
    wszst_yaz0._use_c_module = True
    benchmark(wszst_yaz0.decompress, TEST_FILE_DATA[file])


@pytest.mark.parametrize("file", TEST_FILES)
def test_syaz0(benchmark, file):
    benchmark.group = "decomp: " + file
    benchmark(syaz0.decompress, TEST_FILE_DATA[file])


@pytest.mark.parametrize("file", TEST_FILES)
def test_syaz0_fast(benchmark, file):
    benchmark.group = "decomp: " + file
    benchmark(syaz0.decompress_unsafe, TEST_FILE_DATA[file])


@pytest.mark.parametrize("file", TEST_FILES)
def test_libyaz0(benchmark, file):
    benchmark.group = "decomp: " + file
    benchmark(libyaz0.decompress, TEST_FILE_DATA[file])



import pytest
import libyaz0
import syaz0
import wszst_yaz0
from files import TEST_FILES, TEST_FILE_DATA, TEST_FILE_DATA_UNCOMP


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_libyaz0_lv1(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(libyaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=1)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_libyaz0_lv6(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(libyaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=6)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_libyaz0_lv9(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(libyaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=9)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_syaz0_lv6(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(syaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=6)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_syaz0_lv7(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(syaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=7)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_syaz0_lv8(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(syaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=8)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_syaz0_lv9(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(syaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=9)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_wszst_yaz0_lv1(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(wszst_yaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=1)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_wszst_yaz0_lv6(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(wszst_yaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=6)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_wszst_yaz0_lv9(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(wszst_yaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=9)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_wszst_yaz0_lv10(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(wszst_yaz0.compress, TEST_FILE_DATA_UNCOMP[file], level=10)



import setuptools
import versioneer

import os
import re
import sys
import platform
import subprocess
from pathlib import Path

from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext
from distutils.version import LooseVersion


class CMakeExtension(Extension):
    def __init__(self, name, sourcedir=''):
        Extension.__init__(self, name, sources=[str(p) for p in Path(sourcedir).glob('**/*')])
        self.sourcedir = os.path.abspath(sourcedir)


class CMakeBuild(build_ext):
    def run(self):
        try:
            out = subprocess.check_output(['cmake', '--version'])
        except OSError:
            raise RuntimeError("CMake must be installed to build the following extensions: " +
                               ", ".join(e.name for e in self.extensions))

        if platform.system() == "Windows":
            cmake_version = LooseVersion(re.search(r'version\s*([\d.]+)', out.decode()).group(1))
            if cmake_version < '3.1.0':
                raise RuntimeError("CMake >= 3.1.0 is required on Windows")

        for ext in self.extensions:
            self.build_extension(ext)

    def build_extension(self, ext):
        debug = bool(os.getenv('DEBUG', False))

        extdir = os.path.abspath(os.path.dirname(self.get_ext_fullpath(ext.name)))
        cmake_args = ['-DCMAKE_LIBRARY_OUTPUT_DIRECTORY=' + extdir,
                      '-DPYTHON_EXECUTABLE=' + sys.executable]

        cfg = 'Debug' if debug else 'Release'
        build_args = ['--config', cfg]

        if platform.system() == "Windows":
            cmake_args += ['-DCMAKE_LIBRARY_OUTPUT_DIRECTORY_{}={}'.format(cfg.upper(), extdir)]
            if sys.maxsize > 2**32:
                cmake_args += ['-A', 'x64']
            build_args += ['--', '/m']
        else:
            cmake_args += ['-DCMAKE_BUILD_TYPE=' + cfg]
            build_args += ['--', '-j2']

        env = os.environ.copy()
        env['CXXFLAGS'] = '{} -DVERSION_INFO=\\"{}\\"'.format(env.get('CXXFLAGS', ''),
                                                              self.distribution.get_version())
        if not os.path.exists(self.build_temp):
            os.makedirs(self.build_temp)
        subprocess.check_call(['cmake', ext.sourcedir] + cmake_args, cwd=self.build_temp, env=env)
        subprocess.check_call(['cmake', '--build', '.'] + build_args, cwd=self.build_temp)


with open("README.md", "r") as fh:
    long_description = fh.read()

cmdclass = versioneer.get_cmdclass()
cmdclass["build_ext"] = CMakeBuild

setuptools.setup(
    name="syaz0",
    version=versioneer.get_version(),
    cmdclass=cmdclass,
    author="leoetlino",
    author_email="leo@leolam.fr",
    description="Library for data compression using Nintendo's Yaz0 algorithm",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/zeldamods/syaz0",
    packages=setuptools.find_packages(),
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)",
        "Topic :: Software Development :: Libraries",
        "Operating System :: OS Independent",
        "Programming Language :: C++",
        "Programming Language :: Python :: 3 :: Only",
    ],
    python_requires=">=3.6",
    ext_modules=[CMakeExtension(name="syaz0", sourcedir="src")],
    zip_safe=False,
)
